@@ -37,11 +37,15 @@ class Client:
         self.__verify = True
 
         self.queue = Queue()
+        self.__run_status = 'pause'
 
         self.rabbit_credentials = credentials
         self.consumer = None
         return
 
+    def __update_run_status(self, status):
+        self.__run_status = status
+
     def disable_ssl_verification(self, enabled=False):
         warnings.warn("[BranchKey] We highly recommend enabling ssl verification. Use this at your own risk.")
         self.__verify = enabled
@@ -102,7 +106,7 @@ class Client:
                 self.__status = login_data["status"]
                 self.rabbit_credentials["queue_password"] = self.__access_token
                 self.rabbit_credentials["leaf_id"] = self.__leaf_id
-                consumer = Consumer(self.rabbit_credentials, self.queue)
+                consumer = Consumer(self.rabbit_credentials, self.queue, self.__update_run_status)
                 self.consumer = consumer.spawn_consumer_thread()
                 return self.__status == "logged_in"
             except Exception as e:
@@ -202,3 +206,7 @@ class Client:
     @property
     def is_logged_in(self):
         return self.__status == "logged_in"
+
+    @property
+    def run_status(self):
+        return self.__run_status
